==> haskell-generic-lens-2.2.2.0-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-lens
version:              2.2.2.0
visibility:           public
id:                   generic-lens-2.2.2.0-KrjWcIdSlKk9vRiMN1rim6
key:                  generic-lens-2.2.2.0-KrjWcIdSlKk9vRiMN1rim6
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    The library exposes a van Laarhoven interface. For an alternative interface, supporting an opaque optic type, see
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@.

category:             Generics, Records, Lens
abi:                  d02e1612d1dd0eeb00e0f6a66bf016fb
exposed:              True
exposed-modules:
    Data.Generics.Internal.VL Data.Generics.Internal.VL.Iso
    Data.Generics.Internal.VL.Lens Data.Generics.Internal.VL.Prism
    Data.Generics.Labels Data.Generics.Product
    Data.Generics.Product.Any Data.Generics.Product.Fields
    Data.Generics.Product.HList Data.Generics.Product.Param
    Data.Generics.Product.Positions Data.Generics.Product.Subtype
    Data.Generics.Product.Typed Data.Generics.Product.Types
    Data.Generics.Sum Data.Generics.Sum.Any
    Data.Generics.Sum.Constructors Data.Generics.Sum.Subtype
    Data.Generics.Sum.Typed Data.Generics.Wrapped

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-lens-2.2.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-lens-2.2.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-lens-2.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-lens
hs-libraries:         HSgeneric-lens-2.2.2.0-KrjWcIdSlKk9vRiMN1rim6
depends:
    base-4.17.2.1 generic-lens-core-2.2.1.0-KFFVheAYCuPBp3CIk0gi2Z
    profunctors-5.6.2-FU1ZJ7jAwY3FBezLPRDd4l text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens/html/generic-lens.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-lens-2.2.2.0-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-lens
version:              2.2.2.0
visibility:           public
id:                   generic-lens-2.2.2.0-Cf2MfJviO749OZ9OmgjLdi
key:                  generic-lens-2.2.2.0-Cf2MfJviO749OZ9OmgjLdi
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    The library exposes a van Laarhoven interface. For an alternative interface, supporting an opaque optic type, see
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@.

category:             Generics, Records, Lens
abi:                  6254837cc8383088e82d0615d36eb064
exposed:              True
exposed-modules:
    Data.Generics.Internal.VL Data.Generics.Internal.VL.Iso
    Data.Generics.Internal.VL.Lens Data.Generics.Internal.VL.Prism
    Data.Generics.Labels Data.Generics.Product
    Data.Generics.Product.Any Data.Generics.Product.Fields
    Data.Generics.Product.HList Data.Generics.Product.Param
    Data.Generics.Product.Positions Data.Generics.Product.Subtype
    Data.Generics.Product.Typed Data.Generics.Product.Types
    Data.Generics.Sum Data.Generics.Sum.Any
    Data.Generics.Sum.Constructors Data.Generics.Sum.Subtype
    Data.Generics.Sum.Typed Data.Generics.Wrapped

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-lens-2.2.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-lens-2.2.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-lens-2.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-lens
hs-libraries:         HSgeneric-lens-2.2.2.0-Cf2MfJviO749OZ9OmgjLdi
depends:
    base-4.17.2.1 generic-lens-core-2.2.1.0-KFFVheAYCuPBp3CIk0gi2Z
    profunctors-5.6.2-AAbTLaitJHyFONxazBj3r8 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens/html/generic-lens.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
